[PATCH] D43267: MIRParser: Accept overloaded intrinsic names w/o type suffixes

Roman Tereshin via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Wed Feb 28 15:54:09 PST 2018


This revision was automatically updated to reflect the committed changes.
rtereshin marked 2 inline comments as done.
Closed by commit rL326387: [MIRParser] Accept overloaded intrinsic names w/o type suffixes (authored by rtereshin, committed by ).

Changed prior to commit:
  https://reviews.llvm.org/D43267?vs=134144&id=136416#toc

Repository:
  rL LLVM

https://reviews.llvm.org/D43267

Files:
  llvm/trunk/lib/IR/Function.cpp
  llvm/trunk/test/CodeGen/MIR/AArch64/print-parse-overloaded-intrinsics.mir


Index: llvm/trunk/test/CodeGen/MIR/AArch64/print-parse-overloaded-intrinsics.mir
===================================================================
--- llvm/trunk/test/CodeGen/MIR/AArch64/print-parse-overloaded-intrinsics.mir
+++ llvm/trunk/test/CodeGen/MIR/AArch64/print-parse-overloaded-intrinsics.mir
@@ -0,0 +1,24 @@
+# RUN: llc -mtriple aarch64-- -run-pass irtranslator -simplify-mir %s -o %t \
+# RUN:   -verify-machineinstrs; llc -mtriple aarch64-- -run-pass legalizer \
+# RUN:   -simplify-mir %t -x mir -o - -verify-machineinstrs | FileCheck %s
+
+# Test that MIRParser is able to deserialize back MIR MIRPrinter serialized,
+# specifically overloaded intrinsic names in this case which aren't required
+# to encode all the concrete arg types in the name at MIR level.
+
+--- |
+  define i32 @int_aarch64_sdiv(i32 %a, i32 %b) nounwind readnone ssp {
+  ; CHECK-LABEL: name: int_aarch64_sdiv
+  ; CHECK: liveins: $w0, $w1
+  ; CHECK: [[COPY:%[0-9]+]]:_(s32) = COPY $w0
+  ; CHECK: [[COPY1:%[0-9]+]]:_(s32) = COPY $w1
+  ; CHECK: [[INT:%[0-9]+]]:_(s32) = G_INTRINSIC intrinsic(@llvm.aarch64.sdiv), [[COPY]](s32), [[COPY1]](s32)
+  ; CHECK: $w0 = COPY [[INT]](s32)
+  ; CHECK: RET_ReallyLR implicit $w0
+  entry:
+    %sdiv = call i32 @llvm.aarch64.sdiv.i32(i32 %a, i32 %b)
+    ret i32 %sdiv
+  }
+
+  declare i32 @llvm.aarch64.sdiv.i32(i32, i32) nounwind readnone
+...


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D43267.136416.patch
Type: text/x-patch
Size: 2256 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20180228/e04da19b/attachment.bin>


More information about the llvm-commits mailing list
Index: llvm/trunk/lib/IR/Function.cpp
===================================================================
--- llvm/trunk/lib/IR/Function.cpp
+++ llvm/trunk/lib/IR/Function.cpp
@@ -523,9 +523,11 @@
   Intrinsic::ID ID = static_cast<Intrinsic::ID>(Idx + Adjust);
 
   // If the intrinsic is not overloaded, require an exact match. If it is
-  // overloaded, require a prefix match.
-  bool IsPrefixMatch = Name.size() > strlen(NameTable[Idx]);
-  return IsPrefixMatch == isOverloaded(ID) ? ID : Intrinsic::not_intrinsic;
+  // overloaded, require either exact or prefix match.
+  const auto MatchSize = strlen(NameTable[Idx]);
+  assert(Name.size() >= MatchSize && "Expected either exact or prefix match");
+  bool IsExactMatch = Name.size() == MatchSize;
+  return IsExactMatch || isOverloaded(ID) ? ID : Intrinsic::not_intrinsic;
 }
 
 void Function::recalculateIntrinsicID() {